@@ -5,9 +5,9 @@ use MooseX::Storage;
 with 'MooseX::Storage::Deferred';
 
 use Message::Stack;
-use Message::Stack::DataVerifier;
+use Message::Stack::Parser::DataVerifier;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 has 'messages' => (
     is => 'ro',
@@ -55,7 +55,7 @@ sub _build_messages {
     my $stack = Message::Stack->new;
     foreach my $scope (keys %{ $self->results }) {
         my $results = $self->get_results($scope);
-        Message::Stack::DataVerifier->parse($stack, $scope, $results);
+        Message::Stack::Parser::DataVerifier->parse($stack, $scope, $results);
     }
 
     return $stack;
